@@ -1,5 +1,5 @@
 "are.parcau.valid" <-
-function(para,nowarn=FALSE,...) {
+function(para,nowarn=FALSE) {
     if(! is.cau(para)) return(FALSE)
     U <- para$para[1] 
     A <- para$para[2] 
