@@ -1,6 +1,9 @@
 "quanor" <-
-function(f,para) {
-    if(! are.parnor.valid(para)) return()
+function(f,para,paracheck=TRUE) {
+    if(! check.fs(f)) return()
+    if(paracheck == TRUE) {
+      if(! are.parnor.valid(para)) return()
+    }
     x <- vector(mode="numeric")
     for(i in seq(1,length(f))) {
       x[i] <- qnorm(f[i],mean = para$para[1], sd = para$para[2])
